.. _mixer-api:

***************
Audio mixer API
***************

.. module:: mopidy.mixer
    :synopsis: The audio mixer API

.. autoclass:: mopidy.mixer.Mixer
    :members:

.. autoclass:: mopidy.mixer.MixerListener
    :members:


Mixer implementations
=====================

See :ref:`ext-mixers`.
